==> qtjambi-xml-5.15.7-sources.jar: io/qt/xml/QDomEntityReference.java <==
package io.qt.xml;


/**
 * <p>Represents an XML entity reference</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qdomentityreference.html">QDomEntityReference</a></p>
 */
public class QDomEntityReference extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomentityreference.html#QDomEntityReference">QDomEntityReference::QDomEntityReference()</a></p>
     */
    public QDomEntityReference(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomEntityReference instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomentityreference.html#QDomEntityReference-1">QDomEntityReference::QDomEntityReference(QDomEntityReference)</a></p>
     */
    public QDomEntityReference(io.qt.xml.QDomEntityReference x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomEntityReference instance, io.qt.xml.QDomEntityReference x);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomEntityReference(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomEntityReference clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomEntityReference clone_native(long __this_nativeId);
}

==> qtjambi-xml-5.15.13-sources.jar: io/qt/xml/QDomEntityReference.java <==
package io.qt.xml;


/**
 * <p>Represents an XML entity reference</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdomentityreference.html">QDomEntityReference</a></p>
 */
public class QDomEntityReference extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomentityreference.html#QDomEntityReference">QDomEntityReference::QDomEntityReference()</a></p>
     */
    public QDomEntityReference(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomEntityReference instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomentityreference.html#QDomEntityReference-1">QDomEntityReference::QDomEntityReference(QDomEntityReference)</a></p>
     */
    public QDomEntityReference(io.qt.xml.QDomEntityReference x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomEntityReference instance, io.qt.xml.QDomEntityReference x);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomEntityReference(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomEntityReference clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomEntityReference clone_native(long __this_nativeId);
}
